@@ -1,3 +1,5 @@
+import json
+
 from flask import request
 from grano.lib.exc import BadRequest, NotFound
 
@@ -32,11 +34,12 @@ def get_offset(default=0, field='offset'):
     return max(0, arg_int(field, default=default))
 
 
-def request_data():
+def request_data(overlay={}):
     """ Decode a JSON-formatted POST body. """
     data = request.json
     if data is None:
-        raise BadRequest()
+        data = json.loads(request.form.get('data'))
+    data.update(overlay)
     return data
 
 
@@ -44,3 +47,13 @@ def object_or_404(obj):
     if obj is None:
         raise NotFound()
     return obj
+
+
+def single_arg(name, default=None):
+    vals = [v for v in request.args.getlist(name) if v.strip()]
+    if len(vals) == 0:
+        return default
+    elif len(vals) > 1:
+        raise BadRequest('Too many values given for: %s' % name)
+    else:
+        return vals[0]
