@@ -65,6 +65,12 @@ def rebuild():
     rebuild_()
 
 
+@manager.command
+def adminkey():
+    """ Print the API key for the system account. """
+    print console_account().api_key
+
+
 @manager.command
 def plugins():
     """ List all available plugins. """
